#!/usr/bin/env python3
# -*- encoding: utf-8; py-indent-offset: 4 -*-
# +------------------------------------------------------------+
# |                                                            |
# |             | |             | |            | |             |
# |          ___| |__   ___  ___| | ___ __ ___ | | __          |
# |         / __| '_ \ / _ \/ __| |/ / '_ ` _ \| |/ /          |
# |        | (__| | | |  __/ (__|   <| | | | | |   <           |
# |         \___|_| |_|\___|\___|_|\_\_| |_| |_|_|\_\          |
# |                                   custom code by SVA       |
# |                                                            |
# +------------------------------------------------------------+
#
# Copyright (C) 2021  Jeronimo Wiederhold <jeronimo.wiederhold@sva.de>
#                     for SVA System Vertrieb Alexander GmbH

# Example output
"""
<resourceType>|<severity>|<capacity>|<available>|<statusMessage>
<<<hpe_oneview_appliance:sep(124)>>>
MEMORY|INFO|15842 MB |3888 MB|SUFFICIENT_MEMORY
CPU|INFO|4|4|SUFFICIENT_VCPUS
DISK|INFO|111 GB|17.69 GB|SUFFICIENT_DISK_SPACE
"""

from .agent_based_api.v1 import *
import re

info_list = ["resourceType", "severity", "capacity", "available", "statusMessage"]
state_map = {
    0: State.OK,
    1: State.WARN,
    2: State.CRIT,
    3: State.UNKNOWN
}

def parse_hpe_oneview_appliance(string_table):
    output = []
    for resource in string_table:
        info_map = dict(zip(info_list, resource))
        output.append(info_map)
    return output

register.agent_section(
    name="hpe_oneview_appliance",
    parse_function=parse_hpe_oneview_appliance
)

def discovery_hpe_oneview_appliance(section):
    for resource in section:
        yield Service(item=resource["resourceType"])


def check_hpe_oneview_appliance(item, params, section):
    warn, crit = params["levels"]

    for resource in section:
        if resource["resourceType"] == item:
            cap = re.sub("[^\d.]", "", resource["capacity"])
            avail = re.sub("[^\d.]", "", resource["available"])
            perc = (float(avail)/float(cap)*100)
            print(perc)

            if perc > crit:
                s = State.CRIT
            elif perc > warn:
                s = State.WARN
            else:
                s = State.OK

            yield Result(state=s, summary="{} of {} available: {:.1f}%, Severity: {}".format(resource["available"], resource["capacity"], perc, resource["severity"]), 
                        details=resource["statusMessage"])
            yield Metric(resource["resourceType"] + "_available", float(perc))


register.check_plugin(
    name="hpe_oneview_appliance",
    service_name="Appliance %s",
    check_ruleset_name="hpe_oneview_appliance",
    check_default_parameters={"levels": (100, 100)},
    discovery_function=discovery_hpe_oneview_appliance,
    check_function=check_hpe_oneview_appliance,
)