#!/usr/bin/env python3
# -*- encoding: utf-8; py-indent-offset: 4 -*-
# +------------------------------------------------------------+
# |                                                            |
# |             | |             | |            | |             |
# |          ___| |__   ___  ___| | ___ __ ___ | | __          |
# |         / __| '_ \ / _ \/ __| |/ / '_ ` _ \| |/ /          |
# |        | (__| | | |  __/ (__|   <| | | | | |   <           |
# |         \___|_| |_|\___|\___|_|\_\_| |_| |_|_|\_\          |
# |                                   custom code by SVA       |
# |                                                            |
# +------------------------------------------------------------+
#
# Copyright (C) 2021  Jeronimo Wiederhold <jeronimo.wiederhold@sva.de>
#                     for SVA System Vertrieb Alexander GmbH

# Example output
"""
<uri>|<certStatus>|<expiryDate>
<<<hpe_oneview_ca:sep(124)>>>
/rest/certificates/ca/Infrastructure Management Certificate Authority-internalroot|GOOD|2028-08-06T09:23:34.000Z
/rest/certificates/ca/CZJ71706K5|GOOD|2118-07-13T09:59:37.000Z
/rest/certificates/ca/CZJ7170S95|GOOD|2118-07-13T10:05:20.000Z
"""

from .agent_based_api.v1 import *
from datetime import datetime

info_list = ["name", "certStatus", "expiryDate"]
state_map = {
    0: State.OK,
    1: State.WARN,
    2: State.CRIT,
    3: State.UNKNOWN
}

def parse_hpe_oneview_ca(string_table):
    output = []
    for ca in string_table:
        info_map = dict(zip(info_list, ca))
        output.append(info_map)
        info_map["name"] = info_map["name"].split("/")[-1]

    return output

register.agent_section(
    name="hpe_oneview_ca",
    parse_function=parse_hpe_oneview_ca
)

def discovery_hpe_oneview_ca(section):
    for ca in section:
        yield Service(item=ca["name"])


def check_hpe_oneview_ca(item, params, section):
    map_status = params["map_certStatus"]

    for ca in section:
        if ca["name"] == item:


            expiryDate = datetime.strptime(ca["expiryDate"], "%Y-%m-%dT%H:%M:%S.000Z").strftime("%d.%m.%Y")

            s= state_map[map_status[ca["certStatus"]]]
            summary="Status: {}, ExpiryDate: {}".format(ca["certStatus"], expiryDate)
            
            yield Result(state=s, summary=summary)


register.check_plugin(
    name="hpe_oneview_ca",
    service_name="Cert Auth: %s",
    check_ruleset_name="hpe_oneview_ca",
    check_default_parameters={
        "map_certStatus": {
            "ABOUTTOEXPIRE": 1,
            "BAD": 2,
            "CONFLICT": 2,
            "CRL_EXPIRED": 2,
            "CRL_INVALID": 2,
            "CRL_NOT_FOUND": 2,
            "CRL_NOT_LOADED": 2,
            "CRL_VERIFICATION_FAILED": 2,
            "EXPIRED": 2,
            "GOOD": 0,
            "INVALID": 2,
            "INVALID_CERTPATH": 2,
            "KEY_STORE_NOT_FOUND": 2,
            "NA": 1,
            "NOT_TRUSTED": 1,
            "PARSING_FAILED": 2,
            "REVOCATION_CHECK_NOT_DONE": 1,
            "REVOKED": 2,
            "SUSPENDED": 2
            }
        },
    discovery_function=discovery_hpe_oneview_ca,
    check_function=check_hpe_oneview_ca,
)